@@ -40,9 +40,9 @@
 
 /* Usefull in particular for loadshared where the full path
  * to the lib is needed */
-#define GDCM_SOURCE_DIR "/pobj/gdcm-2.8.4/gdcm-2.8.4"
-#define GDCM_EXECUTABLE_OUTPUT_PATH "/pobj/gdcm-2.8.4/build-mips64/bin"
-#define GDCM_LIBRARY_OUTPUT_PATH    "/pobj/gdcm-2.8.4/build-mips64/bin"
+#define GDCM_SOURCE_DIR "/usr/obj/ports/gdcm-2.8.7/gdcm-2.8.7"
+#define GDCM_EXECUTABLE_OUTPUT_PATH "/usr/obj/ports/gdcm-2.8.7/build-arm/bin"
+#define GDCM_LIBRARY_OUTPUT_PATH    "/usr/obj/ports/gdcm-2.8.7/build-arm/bin"
 
 /* #undef GDCM_BUILD_TESTING */
 
@@ -146,8 +146,8 @@
 /* Version number.  */
 #define GDCM_MAJOR_VERSION 2
 #define GDCM_MINOR_VERSION 8
-#define GDCM_BUILD_VERSION 4
-#define GDCM_VERSION "2.8.4"
+#define GDCM_BUILD_VERSION 7
+#define GDCM_VERSION "2.8.7"
 #define GDCM_API_VERSION "2.8"
 
 /*
